# mach-client-py

A Python client for the Mach exchange, including useful Ethereum utilities.

Note - to change the backend URL from production:

```bash
export MACH_BACKEND_URL='https://cache-half-full-staging.fly.dev'
```
